@@ -1,8 +1,8 @@
 package Dancer2::Core::Request;
 # ABSTRACT: Interface for accessing incoming requests
-$Dancer2::Core::Request::VERSION = '0.166001_01'; # TRIAL
+$Dancer2::Core::Request::VERSION = '0.166001_02'; # TRIAL
 
-$Dancer2::Core::Request::VERSION = '0.16600101';use strict;
+$Dancer2::Core::Request::VERSION = '0.16600102';use strict;
 use warnings;
 use parent 'Plack::Request';
 
@@ -364,18 +364,19 @@ sub _set_route_parameters {
 
 sub body_parameters {
     my $self = shift;
-    $self->{'plack.request.body'}
-        and return $self->{'plack.request.body'};
+    $self->env->{'plack.request.body'}
+        and return $self->env->{'plack.request.body'};
 
     # handle case of serializer
     if ( my $data = $self->deserialize ) {
-        return Hash::MultiValue->from_mixed(
+        $self->env->{'plack.request.body'} = Hash::MultiValue->from_mixed(
             ref $data eq 'HASH' ? %{$data} : ()
         );
+        return $self->env->{'plack.request.body'};
     }
 
-    $self->_parse_request_body;
-    return $self->env->{'plack.request.body'};
+    # defer to (the overridden) Plack::Request->body_parameters
+    return $self->SUPER::body_parameters();
 }
 
 sub parameters {
@@ -632,7 +633,7 @@ Dancer2::Core::Request - Interface for accessing incoming requests
 
 =head1 VERSION
 
-version 0.166001_01
+version 0.166001_02
 
 =head1 SYNOPSIS
 
@@ -1101,7 +1102,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Alexis Sukrieh.
+This software is copyright (c) 2016 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
